==> vtiger-4.2.4.tbz: www/vtiger/modules/Rss/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /cvsroot/vtigercrm/vtiger_crm/modules/Rss/language/en_us.lang.php,v 1.1 2005/05/20 07:12:23 venkatraj Exp $
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'RSS',
'LBL_MODULE_TITLE'=>'RSS: Home',

'LBL_NEW_RSS_ENTRY'=>'New RSS News Feed URL:',
'LBL_SEARCH_RSS'=>'Search Title:',
'LBL_NEW_RSS_BUTTON'=>'Add',

'LBL_STARRED_RSS'=>'Starred Feeds',
'LBL_POP_CRM_RSS'=>'Popular CRM Related Feeds',
'LBL_ALL_RSS_FEEDS'=>'All RSS Feeds'
);
?>

==> vtiger-5.0.3.tbz: www/vtiger/modules/Rss/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'RSS',
'LBL_MODULE_TITLE'=>'RSS: Home',

'LBL_NEW_RSS_ENTRY'=>'New RSS News Feed URL:',
'LBL_SEARCH_RSS'=>'Search Title:',
'LBL_NEW_RSS_BUTTON'=>'Add',

'LBL_STARRED_RSS'=>'Starred Feeds',
'LBL_POP_CRM_RSS'=>'Popular CRM Related Feeds',
'LBL_ALL_RSS_FEEDS'=>'All RSS Feeds',
'LBL_VTIGER_RSS_READER'=>'vtiger RSS Reader',

'LBL_MORE'=>'More...',
'LBL_SUBJECT'=>'Subject',
'LBL_SENDER'=>'Sender',
'LBL_CATEGORY'=>'Category :',
'LBL_FEED'=>'Feed :',
'LBL_FEED_SOURCES'=> 'Feed Sources',
'LBL_ADD_RSS_FEED'=>'Add RSS Feed',
'LBL_DELETE_BUTTON'=>'Delete',
'LBL_SET_DEFAULT_BUTTON'=>'Set As Default',
'LBL_FEEDS_LIST'=>'Feeds list from :',
'LBL_ERROR_MSG'=>'No RSS Feeds are selected or Your Proxy Settings is not Proper',
'LBL_REGRET_MSG'=>'Sorry: It\'s not possible to reach RSS URL',

'UNABLE_TO_SAVE'=>'Unable to save the RSS Feed URL',
'NOT_A_VALID'=>'Not a valid RSS Feed URL',
);
?>
